;;; slovak-calendar.el -- Slovak calendar and holidays

;; Copyright (C) 1998 Milan Zamazal

;; Authors:    David ,B)(Bauer <xsauer@hwlab.felk.cvut.cz>,
;;             Tibor ,B)(Bimko <tibor.simko@fmph.uniba.sk>,
;;             Milan Zamazal <pdm@fi.muni.cz>
;; Maintainer: Milan Zamazal <pdm@fi.muni.cz>
;; Version:    4.0
;; Keywords:   i18n, Slovak, calendar, holidays

;; COPYRIGHT NOTICE
;;
;; This program is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the Free
;; Software Foundation, version 2 of the License.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
;; for more details.
;;
;; You can find the GNU General Public License at
;; http://www.gnu.org/copyleft/gpl.html
;; or you can write to the Free Software Foundation, Inc., 675 Mass Ave.,
;; Cambridge, MA 02139, USA.

;;; Commentary:

;; This file defines and redefines various calendar things according to Slovak
;; national habits.

;;; History:

;; So long, so very long...

;;; Code:

;; Basic calendar settings according to Slovak habits
(setq european-calendar-style t
      calendar-week-start-day 1
      calendar-day-name-array
      ["nede,B5(Ba" "pondelok" "utorok" "streda" ",B9(Btvrtok" "piatok" "sobota"]
      calendar-month-name-array
      ["janu,Ba(Br" "febru,Ba(Br" "marec" "apr,Bm(Bl" "m,Ba(Bj" "j,Bz(Bn"
       "j,Bz(Bl" "august" "september" "okt,Bs(Bber" "november" "december"]
      display-time-24hr-format t
      cal-tex-24 t
      cal-tex-options "slovak"
      calendar-date-display-form '(day ". " month ". " year)
      calendar-time-display-form '(24-hours ":" minutes
					    (if time-zone " (")
					    time-zone
					    (if time-zone ")")))

;; Slovak holidays
(setq local-holidays
      '((holiday-fixed
	 1 1    "De,Br(B vzniku Slovenskej republiky a Nov,B}(B rok")
	(holiday-fixed
	 1 6    "Zjavenie P,Ba(Bna (Traja kr,Ba(Bli a viano,Bh(Bn,B}(B sviatok pravosl,Ba(Bvnych kres,B;(Banov")
	(holiday-fixed
	 2 14   "Sviatok sv. Valent,Bm(Bna")
	(holiday-fixed
	 3 25   "De,Br(B z,Ba(Bpasu za ,B5(Budsk,Bi(B pr,Ba(Bva")
	(holiday-fixed
	 4 1    "Apr,Bm(Bl!")
	(holiday-fixed
	 4 13   "De,Br(B nespravodlivo st,Bm(Bhan,B}(Bch")
	(holiday-fixed
	 5 1    "Sviatok pr,Ba(Bce")
	(holiday-fixed
	 5 4    "V,B}(Bro,Bh(Bie ,Bz(Bmrtia M. R. ,B)(Btef,Ba(Bnika")
	(holiday-float
	 5 0 2  "De,Br(B matiek")
	(holiday-fixed
	 5 8    "De,Br(B v,Bm;(Bazstva nad fa,B9(Bizmom (1945)")
	(holiday-fixed
	 6 7    "V,B}(Bro,Bh(Bie Memoranda n,Ba(Broda slovensk,Bi(Bho (1861)")
	(holiday-fixed
	 7 5    "Sviatok sv,Bd(Bt,Bi(Bho Cyrila a sv,Bd(Bt,Bi(Bho Metoda")
	(holiday-fixed
	 7 17   "V,B}(Bro,Bh(Bie Deklar,Ba(Bcie o zvrchovanosti Slovenskej republiky (1992)")
	(holiday-fixed
	 8 4    "De,Br(B Matice slovenskej")
	(holiday-fixed
	 8 29   "V,B}(Bro,Bh(Bie Slovensk,Bi(Bho n,Ba(Brodn,Bi(Bho povstania")
	(holiday-fixed
	 9 1    "De,Br(B ,BZ(Bstavy Slovenskej republiky")
	(holiday-fixed
	 9 15   "Sedembolestn,Ba(B Panna M,Ba(Bria")
	(holiday-fixed
	 9 19   "De,Br(B prv,Bi(Bho verejn,Bi(Bho vyst,Bz(Bpenia Slovenskej n,Ba(Brodnej rady (1948)")
	(holiday-fixed
	 10 6   "De,Br(B obet,Bm(B Dukly (1944)")
	(holiday-fixed
	 10 27  "De,Br(B ,Bh(Bernovskej trag,Bi(Bdie (1907)")
	(holiday-fixed
	 10 30  "V,B}(Bro,Bh(Bie Deklar,Ba(Bcie slovensk,Bi(Bho n,Ba(Broda (1918)")
	(holiday-fixed
	 10 31  "De,Br(B reform,Ba(Bcie")
	(holiday-fixed
	 11 2   "Sviatok v,B9(Betk,B}(Bch sv,Bd(Bt,B}(Bch")
	(holiday-fixed
	 11 17  "De,Br(B boja proti totalite (1989)")
	(holiday-fixed
	 12 24  ",B)(Btedr,B}(B de,Br(B")
	(holiday-fixed
	 12 26  "Druh,B}(B viano,Bh(Bn,B}(B sviatok")
	(holiday-fixed
	 12 31  "Silvester")))

;; Translate daylight savings time
(setq solar-holidays
  '((solar-equinoxes-solstices)
    (funcall
     'holiday-sexp
     calendar-daylight-savings-starts
     '(format "Za,Bhm(Bna letn,B}(B ,Bh(Bas"))
    (funcall
     'holiday-sexp
     calendar-daylight-savings-ends
     '(format "Kon,Bhm(B letn,B}(B ,Bh(Bas"))))

;; Translate solar seasons
(setq solar-n-hemi-seasons
  '("Jarn,Ba(B rovnodennos,B;(B" "Letn,B}(B slnovrat" 
    "Jesenn,Ba(B rovnodennos,B;(B" "Zimn,B}(B slnovrat"))

;; Translate Christian holidays
(setq christian-holidays
  '((if all-christian-calendar-holidays
        (holiday-fixed 1 6 "Traja kr,Ba(Bli"))
    (cz-holiday-easter-etc)
    (if all-christian-calendar-holidays
        (holiday-greek-orthodox-easter))
    (if all-christian-calendar-holidays
        (holiday-fixed 8 15 "Nanebovzatie Panny M,Ba(Brie"))
    (if all-christian-calendar-holidays
        (holiday-advent))
    (holiday-fixed 12 25 "Prv,B}(B viano,Bh(Bn,B}(B sviatok")
    (if all-christian-calendar-holidays
        (holiday-julian 12 25 "Pravosl,Ba(Bvne Vianoce"))))

;; Another replacing case.  Cut, paste & edit from `holidays.el' again.
;; Here we moreover slightly modify produced list, because in Slovak Republic
;; there is another set of mandatory Easter holidays.
(defun cz-holiday-easter-etc ()
  "List of dates related to Easter, as visible in calendar window."
  (if (and (> displayed-month 5) (not all-christian-calendar-holidays))
      nil;; Ash Wednesday, Good Friday, and Easter are not visible.
    (let* ((century (1+ (/ displayed-year 100)))
	   (shifted-epact;; Age of moon for April 5...
	    (% (+ 14 (* 11 (% displayed-year 19));;     ...by Nicaean rule
		  (-;; ...corrected for the Gregorian century rule
		   (/ (* 3 century) 4))
		  (/;; ...corrected for Metonic cycle inaccuracy.
		   (+ 5 (* 8 century)) 25)
		  (* 30 century));;              Keeps value positive.
	       30))
	   (adjusted-epact;;  Adjust for 29.5 day month.
	    (if (or (= shifted-epact 0)
		    (and (= shifted-epact 1) (< 10 (% displayed-year 19))))
		(1+ shifted-epact)
	      shifted-epact))
	   (paschal-moon;; Day after the full moon on or after March 21.
	    (- (calendar-absolute-from-gregorian
		(list 4 19 displayed-year))
	       adjusted-epact))
	   (abs-easter (calendar-dayname-on-or-before
			0 (+ paschal-moon 7)))
	   (mandatory
	    (list
	     (list (calendar-gregorian-from-absolute abs-easter)
		   "Ve,B5(Bkono,Bh(Bn,Ba(B nede,B5(Ba")
	     (list (calendar-gregorian-from-absolute (1+ abs-easter))
		   "Ve,B5(Bkono,Bh(Bn,B}(B pondelok")))
	   (optional
	    (list
	     (list (calendar-gregorian-from-absolute (- abs-easter 49))
		   "Fa,B9(Biangov,Ba(B nede,B5(Ba")
	     (list (calendar-gregorian-from-absolute (- abs-easter 48))
		   "Fa,B9(Biangov,B}(B pondelok")
	     (list (calendar-gregorian-from-absolute (- abs-easter 47))
		   "Fa,B9(Biangov,B}(B utorok")
	     (list (calendar-gregorian-from-absolute (- abs-easter 46))
		   "Popolcov,Ba(B streda")
	     (list (calendar-gregorian-from-absolute (- abs-easter 42))
		   "Prv,Ba(B p,Bt(Bstna nede,B5(Ba")
	     (list (calendar-gregorian-from-absolute (- abs-easter 14))
		   "Piata p,Bt(Bstna nede,B5(Ba")
	     (list (calendar-gregorian-from-absolute (- abs-easter 7))
		   "Nede,B5(Ba utrpenia P,Ba(Bna (Kvetn,Ba(B)")
	     (list (calendar-gregorian-from-absolute (- abs-easter 3))
		   "Zelen,B}(B ,B9(Btvrtok")
	     (list (calendar-gregorian-from-absolute (- abs-easter 2))
		   "Ve,B5(Bk,B}(B piatok")
	     (list (calendar-gregorian-from-absolute (- abs-easter 1))
		   "Sv,Bd(Bt,Ba(B (Ve,B5(Bk,Ba(B) sobota")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 35))
		   "Piata ve,B5(Bkono,Bh(Bn,Ba(B nede,B5(Ba")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 39))
		   "Nanebovst,Bz(Bpenie P,Ba(Bna")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 49))
		   "Sv,Bd(Btodu,B9(Bn,Ba(B nede,B5(Ba (Tur,Bm(Bce)")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 50))
		   "Sv,Bd(Btodu,B9(Bn,B}(B pondelok")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 56))
		   "Najsv,Bd(Btej,B9(Bia Trojica")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 60))
		   "Najsv,Bd(Btej,B9(Bie Kristovo telo a krv (Bo,B>(Bie Telo)")))
	   (output-list
	    (filter-visible-calendar-holidays mandatory)))
      (if all-christian-calendar-holidays
	  (setq output-list
		(append 
		 (filter-visible-calendar-holidays optional)
		 output-list)))
      output-list)))


;;; *** Announce ***

(provide 'slovak-calendar)


;;; slovak-calendar.el ends here

